from airflow.models import BaseOperator
from airflow.utils.decorators import apply_defaults
from airflow.exceptions import AirflowException
from airflow.plugins_manager import AirflowPlugin

import logging
import zenduty


class ZendutyIncidentOperator(BaseOperator):
    """
    Creates ZenDuty Incidents.

    ENV_VARIABLES:
    api_key = API Key set generated by Zenduty (Required)
    title = Title of the incident that is to be created.
    integration_id = The Integration_id generated by one-way API  (Required)
    summary = Summary for the incident to be created
    """

    @apply_defaults
    def __init__(self,
                 api_key=None,
                 title='Title has not been set',
                 integration_id=None,
                 summary='Summary has not been set',
                 *args,
                 **kwargs):
        super(ZendutyIncidentOperator, self).__init__(*args, **kwargs)
        self.api_key = api_key
        self.title = title
        self.integration_id = integration_id
        self.summary = summary

    def execute(self, **kwargs):
        if (self.api_key == None):
            msg = 'Zenduty API Key is not set'
            logging.error(msg)
            raise AirflowException(msg)
        try:
            api_obj = zenduty.EventsApi(zenduty.ApiClient(self.api_key))
            body = {'message': "[Airflow] - {}".format(self.title),
                    'summary': self.summary,
                    'alert_type': "critical",
                    'supressed': False}
            response = api_obj.create_event(self.integration_id, body)
            if(response.status == 201):
                print("Zenduty Alert Sent.")
                logging.info("Zenduty API Successfully executed")
            else:
                logging.error(response.data)
                raise AirflowException(response.data)

        except Exception as ex:
            msg = "Zenduty API call failed ({})".format(ex)
            logging.error(msg)
            raise AirflowException(msg)


# Defining the plugin class
class ZendutyDutyPlugin(AirflowPlugin):
    name = "zenduty"
    operators = [ZendutyIncidentOperator]
